cal.Tasks (Tasks) — amici1

# `cal.Tasks` (Tasks)

Columns

- `<django.db.models.fields.BigAutoField: id>`

- `<django.db.models.fields.DateTimeField: modified>`

- `<django.db.models.fields.DateTimeField: created>`

- `<django.db.models.fields.DateField: start_date>`

- `<lino.core.fields.TimeField: start_time>`

- `<django.db.models.fields.related.ForeignKey: user>`

- `<django.db.models.fields.related.ForeignKey: owner_type>`

- `<lino.modlib.gfks.fields.GenericForeignKeyIdField: owner_id>`

- `<django.db.models.fields.CharField: summary>`

- `<lino.core.fields.RichTextField: description>`

- `<lino.core.choicelists.ChoiceListField: access_class>`

- `<django.db.models.fields.IntegerField: sequence>`

- `<django.db.models.fields.IntegerField: auto_type>`

- `<lino.core.choicelists.ChoiceListField: priority>`

- `<django.db.models.fields.DateField: due_date>`

- `<lino.core.fields.TimeField: due_time>`

- `<django.db.models.fields.IntegerField: percent>`

- `<lino.core.choicelists.ChoiceListField: state>`

- `<lino.modlib.gfks.fields.GenericForeignKey object at 0x7fc82646f198>`

Detail fields

- `<Panel main_1 in lino.core.layouts.DetailLayout on lino_xl.lib.cal.ui.Tasks>`

- Short description (summary) : See `<django.db.models.fields.CharField: summary>`.

- Author (user) : The author of this object. A pointer to lino.modlib.users.models.User.

- `<Panel main_4 in lino.core.layouts.DetailLayout on lino_xl.lib.cal.ui.Tasks>`

- Description (description) : See `<lino.core.fields.RichTextField: description>`.

Actions

- HTML (show_as_html) : Show this table in Bootstrap3 interface

- Table (landscape) (as_pdf) : Show this table as a pdf document.

- Table (portrait) (as_pdf_p) : Show this table as a pdf document.

- Export to .xls (export_excel) : Export this table as an .xls document

- None (grid_post) : See `<lino.core.actions.CreateRow grid_post>`.

- None (grid_put) : See `<lino.core.actions.SaveGridCell grid_put>`.

- New (insert) : Open a dialog window to insert a new Task.

- Create (submit_insert) : Create the record and open a detail window on it

- Detail (detail) : Open a detail window on this record.

- Delete (delete_selected) : Delete this record

- Upload files (show_uploads) : Show uploads in a grid table.

- None (grid) : See `<lino.core.actions.ShowTable grid>`.

- None (open_help) : See `<lino.core.actions.OpenHelpWindow open_help>`.

- None (validate) : See `<lino.core.actions.ValidateForm validate>`.

- Save (submit_detail) : Save changes in this form

- Reopen (wf1) : To do

- ☑ (wf2) : Done

- ☒ (wf3) : Cancelled

- ⚠ (wf4) : Important

Filter parameters

- `<django.db.models.fields.DateField: start_date>`

- `<django.db.models.fields.DateField: end_date>`

- `<django.db.models.fields.related.ForeignKey: user>`

- `<lino.core.fields.DummyField object at 0x7fc81ce94b38>`

- `<lino.core.choicelists.ChoiceListField: state>`

## Filter parameters